Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(8)

Unified Diff: src/api.cc

Issue 18094: Fix a bunch of spelling mistakes :\ (Closed)
Patch Set: More fixes. Created 11 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | src/assembler-arm.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/api.cc
diff --git a/src/api.cc b/src/api.cc
index 92ee5730f8b90375e36bde6f85bfaeb751531a65..252900290d79b7abeba0a6500485ca1f51bf4dff 100644
--- a/src/api.cc
+++ b/src/api.cc
@@ -140,7 +140,7 @@ static inline bool ApiCheck(bool condition,
static bool ReportV8Dead(const char* location) {
FatalErrorCallback callback = GetFatalErrorHandler();
- callback(location, "V8 is no longer useable");
+ callback(location, "V8 is no longer usable");
return true;
}
@@ -153,7 +153,7 @@ static bool ReportEmptyHandle(const char* location) {
/**
* IsDeadCheck checks that the vm is useable. If, for instance, the vm has been
* out of memory at some point this check will fail. It should be called on
* entry to all methods that touch anything in the heap, except destructors
* which you sometimes can't avoid calling after the vm has crashed. Functions
@@ -153,7 +153,7 @@ static bool ReportEmptyHandle(const char* location) {
/**
- * IsDeadCheck checks that the vm is useable. If, for instance, the vm has been
+ * IsDeadCheck checks that the vm is usable. If, for instance, the vm has been
* out of memory at some point this check will fail. It should be called on
* entry to all methods that touch anything in the heap, except destructors
« no previous file with comments | « no previous file | src/assembler-arm.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698